@@ -31,6 +31,7 @@ while [ $# -gt 0 ]; do
             echo "  X86:     x86, x86_64"
             echo "  MIPS:    mips, mips64."
             echo "Use --release to build in release mode"
+            echo "Use --signrelease to build in release mode and sign apk, see vlc-android/build.gradle"
             echo "Use -s to set your keystore file and -p for the password"
             echo "Use -c to get a ChromeOS build"
             echo "Use -l to build only LibVLC"
@@ -46,6 +47,10 @@ while [ $# -gt 0 ]; do
         -r|release|--release)
             RELEASE=1
             ;;
+        signrelease|--signrelease)
+            SIGNED_RELEASE=1
+            RELEASE=1
+            ;;
         -s|--signature)
             KEYSTORE_FILE=$2
             shift
@@ -217,7 +222,7 @@ fi
 # Fetch VLC source #
 ####################
 
-TESTED_HASH=3fdb5dc
+TESTED_HASH=bdb4031
 if [ ! -d "vlc" ]; then
     diagnostic "VLC source not found, cloning"
     git clone http://git.videolan.org/git/vlc.git vlc
@@ -262,7 +267,9 @@ fi
 ##################
 PLATFORM="Vanilla"
 BUILDTYPE="Debug"
-if [ "$RELEASE" = 1 ]; then
+if [ "$SIGNED_RELEASE" = 1 ]; then
+    BUILDTYPE="signedRelease"
+elif [ "$RELEASE" = 1 ]; then
     BUILDTYPE="Release"
 fi
 if [ "$CHROME_OS" = 1 ]; then
