@@ -621,7 +621,12 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
             mPlaying = false;
             mAudioReset = true;
         }
-        nativeStop();
+        new Thread(new Runnable() {
+            @Override
+            public void run() {
+                nativeStop();
+            }
+        }).start();
     }
 
     /**
@@ -977,7 +982,7 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
      * @return true on success.
      */
     public boolean addSlave(int type, Uri uri, boolean select) {
-        return nativeAddSlave(type, VLCUtil.locationFromUri(uri), select);
+        return nativeAddSlave(type, VLCUtil.encodeVLCUri(uri), select);
     }
 
     /**
