@@ -22,13 +22,10 @@
  */
 package org.videolan.vlc.gui.browser;
 
-import android.content.SharedPreferences;
 import android.databinding.ViewDataBinding;
 import android.graphics.BitmapFactory;
 import android.graphics.drawable.BitmapDrawable;
-import android.preference.PreferenceManager;
 import android.support.annotation.MainThread;
-import android.support.v7.util.DiffUtil;
 import android.support.v7.widget.RecyclerView;
 import android.text.TextUtils;
 import android.view.LayoutInflater;
@@ -42,42 +39,33 @@ import org.videolan.medialibrary.media.MediaLibraryItem;
 import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.medialibrary.media.Storage;
 import org.videolan.vlc.R;
+import org.videolan.vlc.SortableAdapter;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.databinding.BrowserItemBinding;
 import org.videolan.vlc.databinding.BrowserItemSeparatorBinding;
-import org.videolan.vlc.gui.BaseQueuedAdapter;
 import org.videolan.vlc.gui.helpers.UiTools;
-import org.videolan.vlc.util.MediaItemDiffCallback;
 import org.videolan.vlc.util.MediaItemFilter;
+import org.videolan.vlc.util.Util;
 
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Comparator;
 import java.util.List;
-import java.util.Locale;
 
 import static org.videolan.medialibrary.media.MediaLibraryItem.FLAG_SELECTED;
 import static org.videolan.medialibrary.media.MediaLibraryItem.TYPE_MEDIA;
 import static org.videolan.medialibrary.media.MediaLibraryItem.TYPE_STORAGE;
 
-public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibraryItem>, BaseBrowserAdapter.ViewHolder> implements Filterable {
+public class BaseBrowserAdapter extends SortableAdapter<MediaLibraryItem, BaseBrowserAdapter.ViewHolder> implements Filterable {
     protected static final String TAG = "VLC/BaseBrowserAdapter";
 
     private static int FOLDER_RES_ID = R.drawable.ic_menu_folder;
 
-    private final static int SORT_BY_TITLE = 0;
-    private final static int SORT_BY_LENGTH = 1;
-    private final static int SORT_BY_DATE = 2;
-    private final static int SORT_DEFAULT = 4;
-    private static MediaComparator sMediaComparator = new MediaComparator();
-
     private static final BitmapDrawable IMAGE_FOLDER = new BitmapDrawable(VLCApplication.getAppResources(), BitmapFactory.decodeResource(VLCApplication.getAppResources(), FOLDER_RES_ID));
     private static final BitmapDrawable IMAGE_AUDIO = new BitmapDrawable(VLCApplication.getAppResources(), BitmapFactory.decodeResource(VLCApplication.getAppResources(), R.drawable.ic_browser_audio_normal));
     private static final BitmapDrawable IMAGE_VIDEO = new BitmapDrawable(VLCApplication.getAppResources(), BitmapFactory.decodeResource(VLCApplication.getAppResources(), R.drawable.ic_browser_video_normal));
     private static final BitmapDrawable IMAGE_SUBTITLE = new BitmapDrawable(VLCApplication.getAppResources(), BitmapFactory.decodeResource(VLCApplication.getAppResources(), R.drawable.ic_browser_subtitle_normal));
     private static final BitmapDrawable IMAGE_UNKNOWN = new BitmapDrawable(VLCApplication.getAppResources(), BitmapFactory.decodeResource(VLCApplication.getAppResources(), R.drawable.ic_browser_unknown_normal));
 
-    volatile ArrayList<MediaLibraryItem> mMediaList = new ArrayList<>();
     private ArrayList<MediaLibraryItem> mOriginalData = null;
     protected final BaseBrowserFragment fragment;
     private int mTop = 0, mMediaCount = 0, mSelectionCount = 0;
@@ -103,7 +91,7 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
             onBindMediaViewHolder((MediaViewHolder) holder, position);
         } else {
             SeparatorViewHolder vh = (SeparatorViewHolder) holder;
-            vh.binding.setTitle(mMediaList.get(position).getTitle());
+            vh.binding.setTitle(mDataset.get(position).getTitle());
         }
     }
 
@@ -131,7 +119,11 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
 
     @Override
     public int getItemCount() {
-        return mMediaList.size();
+        return mDataset.size();
+    }
+
+    public MediaLibraryItem get(int position) {
+        return mDataset.get(position);
     }
 
     public abstract class ViewHolder<T extends ViewDataBinding> extends RecyclerView.ViewHolder {
@@ -188,21 +180,21 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
 
         public void onClick(View v){
             int position = getLayoutPosition();
-            if (position < mMediaList.size() && position >= 0)
-                fragment.onClick(v, position, mMediaList.get(position));
+            if (position < mDataset.size() && position >= 0)
+                fragment.onClick(v, position, mDataset.get(position));
         }
 
         public void onMoreClick(View v) {
             int position = getLayoutPosition();
-            if (position < mMediaList.size() && position >= 0)
-                fragment.onCtxClick(v, position, mMediaList.get(position));
+            if (position < mDataset.size() && position >= 0)
+                fragment.onCtxClick(v, position, mDataset.get(position));
         }
 
         @Override
         public boolean onLongClick(View v) {
             int position = getLayoutPosition();
-            return position < mMediaList.size() && position >= 0
-                && fragment.onLongClick(v, position, mMediaList.get(position));
+            return position < mDataset.size() && position >= 0
+                && fragment.onLongClick(v, position, mDataset.get(position));
         }
 
         private void setViewBackground(boolean focus, boolean selected) {
@@ -232,13 +224,7 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
     }
 
     public boolean isEmpty() {
-        ArrayList<MediaLibraryItem> newerList = peekLast();
-        return newerList == null || newerList.isEmpty();
-    }
-
-    @Override
-    public ArrayList<MediaLibraryItem> peekLast() {
-        return hasPendingUpdates() ? super.peekLast() : mMediaList;
+        return Util.isListEmpty(peekLast());
     }
 
     public void addItem(MediaLibraryItem item, boolean top) {
@@ -253,9 +239,6 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
         else
             position = top ? mTop : list.size();
 
-        if (item .getItemType() == TYPE_MEDIA && (((MediaWrapper) item).getType() == MediaWrapper.TYPE_VIDEO || ((MediaWrapper) item).getType() == MediaWrapper.TYPE_AUDIO))
-            mMediaCount++;
-
         if (position <= list.size()) {
             list.add(position, item);
             update(list);
@@ -266,14 +249,10 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
         mTop = top;
     }
 
-    public void addAll(ArrayList<? extends MediaLibraryItem> mediaList) {
-        update((ArrayList<MediaLibraryItem>) mediaList);
-    }
-
     void removeItem(int position) {
         if (position >= getItemCount())
             return;
-        removeItem(mMediaList.get(position));
+        removeItem(mDataset.get(position));
     }
 
     void removeItem(MediaLibraryItem item) {
@@ -287,7 +266,7 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
     void removeItem(String path) {
 
         MediaLibraryItem mediaItem = null;
-        for (MediaLibraryItem item : mMediaList) {
+        for (MediaLibraryItem item : mDataset) {
             if (item .getItemType() == TYPE_MEDIA && TextUtils.equals(path, ((MediaWrapper) item).getUri().toString())) {
                 mediaItem = item;
                 break;
@@ -298,13 +277,13 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
     }
 
     public ArrayList<MediaLibraryItem> getAll(){
-        return mMediaList;
+        return mDataset;
     }
 
     public MediaLibraryItem getItem(int position){
-        if (position < 0 || position >= mMediaList.size())
+        if (position < 0 || position >= mDataset.size())
             return null;
-        return mMediaList.get(position);
+        return mDataset.get(position);
     }
 
     public int getItemViewType(int position){
@@ -341,7 +320,7 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
 
     ArrayList<MediaWrapper> getSelection() {
         ArrayList<MediaWrapper> selection = new ArrayList<>();
-        for (MediaLibraryItem item : mMediaList) {
+        for (MediaLibraryItem item : mDataset) {
             if (item.hasStateFlags(FLAG_SELECTED))
                 selection.add((MediaWrapper) item);
         }
@@ -368,29 +347,23 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
         return mFilter;
     }
 
-    protected void internalUpdate(final ArrayList<MediaLibraryItem> items, final boolean detectMoves) {
-        VLCApplication.runBackground(new Runnable() {
-            @Override
-            public void run() {
-                if (detectMoves || (fragment.isSortEnabled() && sMediaComparator.sortBy != SORT_DEFAULT))
-                    Collections.sort(items, sMediaComparator);
-                final DiffUtil.DiffResult result = DiffUtil.calculateDiff(new MediaItemDiffCallback(mMediaList, items), detectMoves);
-                for (MediaLibraryItem item : items) {
-                    if (item.getItemType() == MediaLibraryItem.TYPE_MEDIA
-                            && (((MediaWrapper)item).getType() == MediaWrapper.TYPE_AUDIO|| (AndroidUtil.isHoneycombOrLater && ((MediaWrapper)item).getType() == MediaWrapper.TYPE_VIDEO)))
-                        mMediaCount++;
-                }
-                VLCApplication.runOnMainThread(new Runnable() {
-                    @Override
-                    public void run() {
-                        mMediaList = items;
-                        result.dispatchUpdatesTo(BaseBrowserAdapter.this);
-                        fragment.onUpdateFinished(null);
-                        processQueue();
-                    }
-                });
-            }
-        });
+    @Override
+    protected ArrayList<MediaLibraryItem> prepareList(ArrayList<MediaLibraryItem> list) {
+        if (fragment.isSortEnabled() && needsSorting())
+            Collections.sort(list, sMediaComparator);
+        mMediaCount = 0;
+        for (MediaLibraryItem item : list) {
+            if (item.getItemType() == MediaLibraryItem.TYPE_MEDIA
+                    && (((MediaWrapper)item).getType() == MediaWrapper.TYPE_AUDIO|| (AndroidUtil.isHoneycombOrLater && ((MediaWrapper)item).getType() == MediaWrapper.TYPE_VIDEO)))
+                ++mMediaCount;
+        }
+        return list;
+    }
+
+    @Override
+    protected void onUpdateFinished() {
+        super.onUpdateFinished();
+        fragment.onUpdateFinished(null);
     }
 
     void restoreList() {
@@ -405,7 +378,7 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
         @Override
         protected List<MediaLibraryItem> initData() {
             if (mOriginalData == null)
-                mOriginalData = new ArrayList<>(mMediaList);
+                mOriginalData = new ArrayList<>(mDataset);
             return mOriginalData;
         }
 
@@ -414,103 +387,4 @@ public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibrary
             update((ArrayList<MediaLibraryItem>) filterResults.values);
         }
     }
-
-    int sortDirection(int sortDirection) {
-        return sMediaComparator.sortDirection(sortDirection);
-    }
-
-    void sortBy(int sortby) {
-        sMediaComparator.sortBy(sortby);
-        update(new ArrayList<>(mMediaList), true);
-    }
-
-
-    private static class MediaComparator implements Comparator<MediaLibraryItem> {
-
-        private static final String KEY_SORT_BY =  "sort_by";
-        private static final String KEY_SORT_DIRECTION =  "sort_direction";
-
-        private static int sortDirection;
-        private static int sortBy = SORT_DEFAULT;
-        protected static SharedPreferences settings = PreferenceManager.getDefaultSharedPreferences(VLCApplication.getAppContext());
-
-        MediaComparator() {
-            sortBy = settings.getInt(KEY_SORT_BY, SORT_BY_TITLE);
-            sortDirection = settings.getInt(KEY_SORT_DIRECTION, 1);
-        }
-
-        int sortDirection(int sortby) {
-            if (sortby == sortBy)
-                return  sortDirection;
-            else
-                return -1;
-        }
-
-        void sortBy(int sortby) {
-            switch (sortby) {
-                case SORT_BY_TITLE:
-                    if (sortBy == SORT_BY_TITLE)
-                        sortDirection *= -1;
-                    else {
-                        sortBy = SORT_BY_TITLE;
-                        sortDirection = 1;
-                    }
-                    break;
-                case SORT_BY_LENGTH:
-                    if (sortBy == SORT_BY_LENGTH) {
-                        sortDirection *= -1;
-                    }
-                    else {
-                        sortBy = SORT_BY_LENGTH;
-                        sortDirection *= 1;
-                    }
-                    break;
-                case SORT_BY_DATE:
-                    if (sortBy == SORT_BY_DATE)
-                        sortDirection *= -1;
-                    else {
-                        sortBy = SORT_BY_DATE;
-                        sortDirection *= 1;
-                    }
-                    break;
-                default:
-                    sortBy = SORT_BY_TITLE;
-                    sortDirection = 1;
-                    break;
-            }
-            settings.edit()
-                    .putInt(KEY_SORT_BY, sortBy)
-                    .putInt(KEY_SORT_DIRECTION, sortDirection)
-                    .apply();
-        }
-
-        @Override
-        public int compare(MediaLibraryItem item1, MediaLibraryItem item2) {
-            if (item1 == null)
-                return item2 == null ? 0 : -1;
-            else if (item2 == null)
-                return 1;
-
-            int type1 = ((MediaWrapper)item1).getType();
-            int type2 = ((MediaWrapper)item2).getType();
-            if (type1 == MediaWrapper.TYPE_DIR && type2 != MediaWrapper.TYPE_DIR)
-                return -1;
-            else if (type1 != MediaWrapper.TYPE_DIR && type2 == MediaWrapper.TYPE_DIR)
-                return 1;
-
-            int compare = 0;
-            switch (sortBy) {
-                case SORT_BY_TITLE:
-                    compare = item1.getTitle().toUpperCase(Locale.ENGLISH).compareTo(item2.getTitle().toUpperCase(Locale.ENGLISH));
-                    break;
-                case SORT_BY_LENGTH:
-                    compare = ((Long) ((MediaWrapper)item1).getLength()).compareTo(((MediaWrapper)item2).getLength());
-                    break;
-                case SORT_BY_DATE:
-                    compare = ((Long) ((MediaWrapper)item1).getLastModified()).compareTo(((MediaWrapper)item2).getLastModified());
-                    break;
-            }
-            return sortDirection * compare;
-        }
-    }
 }
